# Name of your project (example according to this example project folder: Simple PyPI Template)
Short description about your project

This is a template, maybe you do not need all of these points, or you need add new ones.

**Note:** if you are reading this from PyPI this is only an example of this template, you do no install this project with 
PIP because it is only a folder with templates (this not have any functionally). To get full template go to 
https://github.com/Invarato/simple_pypi_template_project and pull or download project folder that it is the 
full template. For more information, tricks, easy steps to create your own Python module and upload to PyPi go to 
https://github.com/Invarato/simple_pypi_template_project/blob/master/README_AND_DELETE.md


## Table of contents
 * [Technologies](#technologies)
 * [Setup](#setup)
 * [Quick use](#quick-use)
 * [Documentation](#documentation)
 * [Limitations](#limitations)
 * [Roadmap](#roadmap)
 * [Contributions](#contributions)
 * [License](#license)


## Technologies
Project create with:
 * Python <<< VERSION >>>


## Setup
Install it locally using PyPI:
```
pip install simple-pypi-template
```

## Quick use
Simply and functional example/s of use.

Example:

```python
from citadelml import upload_model

data_returned = upload_model(1000, "str to pass")

print(data_returned)
```

## Documentation
Explain functions, variables and classes. It is better than you be brief here because documentation is inline in code.

If you have a `web site with the documentation`, this point is redundant.

### simple_pypi_template
#### Functions
 * func_of_my_module
 * func_of_my_module_create_file

### submodule
#### Functions
 * func_of_submodule


## Limitations
If this project have some limitation, (for example if this project not work in some systems), it is good to define.
Maybe this limitation will remove in the future (add to roadmap).



## Contact
Contact me via: <<< EMAIL or WAY TO CONTACT >>>



## Roadmap
Future improvements (Remove limitations).
 * One improvement
 * Fix something
 * etc...


## Contributions
Name of people or companies than contribute to this project.

If you add `contributors file` to this project, this point is redundant.


## License
Type of license of this project (Example: MIT license)

If you add `LICENSE file` to this project, this point is redundant.
